Database models for Garmin data
This module contains data models used throughout the application. The models were originally designed for DuckDB but are now used with Parquet storage for concurrent read access.
Re-exports
pub use models::*;
Modules
- models
- Database models matching schema tables